==> lightly_train-0.3.0-py3-none-any.whl: lightly_train/_data/image_dataset.py <==
#
# Copyright (c) Lightly AG and affiliates.
# All rights reserved.
#
# This source code is licensed under the license found in the
# LICENSE file in the root directory of this source tree.
#
from __future__ import annotations

from collections.abc import Iterable, Sequence, Set
from pathlib import Path
from typing import Callable, NewType

from PIL import Image
from PIL.Image import Image as PILImage
from torch import Tensor
from torch.utils.data import Dataset

ImageFilename = NewType("ImageFilename", str)


class ImageDataset(Dataset):
    def __init__(
        self,
        image_dir: Path,
        image_filenames: Sequence[ImageFilename],
        transform: Callable[[PILImage], PILImage | Tensor] | None = None,
    ):
        self.image_dir = image_dir
        self.image_filenames = image_filenames
        self.transform = transform

    def __getitem__(self, idx: int) -> tuple[PILImage | Tensor, ImageFilename]:
        filename = self.image_filenames[idx]
        image = Image.open(self.image_dir / filename)
        if self.transform is not None:
            return self.transform(image), filename
        return image, filename

    def __len__(self) -> int:
        return len(self.image_filenames)


def list_image_filenames(image_dir: Path) -> Iterable[ImageFilename]:
    """List image filenames relative to `image_dir` recursively.

    Args:
        image_dir:
            The root directory to scan for images.

    Returns:
        An iterable of image filenames relative to `image_dir`.
    """
    return (
        ImageFilename(str(fpath.relative_to(image_dir)))
        for fpath in _get_image_filepaths(image_dir=image_dir)
    )


def _get_image_filepaths(image_dir: Path) -> Iterable[Path]:
    extensions = _pil_supported_image_extensions()
    return (
        fpath for fpath in image_dir.rglob("*") if fpath.suffix.lower() in extensions
    )


def _pil_supported_image_extensions() -> Set[str]:
    return {
        ex
        for ex, format in Image.registered_extensions().items()
        if format in Image.OPEN
    }

==> lightly_train-0.3.1-py3-none-any.whl: lightly_train/_data/image_dataset.py <==
#
# Copyright (c) Lightly AG and affiliates.
# All rights reserved.
#
# This source code is licensed under the license found in the
# LICENSE file in the root directory of this source tree.
#
from __future__ import annotations

from collections.abc import Iterable, Sequence, Set
from pathlib import Path
from typing import Callable, NewType

from PIL import Image
from PIL.Image import Image as PILImage
from torch import Tensor
from torch.utils.data import Dataset

ImageFilename = NewType("ImageFilename", str)


class ImageDataset(Dataset):
    def __init__(
        self,
        image_dir: Path,
        image_filenames: Sequence[ImageFilename],
        transform: Callable[[PILImage], PILImage | Tensor] | None = None,
    ):
        self.image_dir = image_dir
        self.image_filenames = image_filenames
        self.transform = transform

    def __getitem__(self, idx: int) -> tuple[PILImage | Tensor, ImageFilename]:
        filename = self.image_filenames[idx]
        image = Image.open(self.image_dir / filename).convert("RGB")
        if self.transform is not None:
            return self.transform(image), filename
        return image, filename

    def __len__(self) -> int:
        return len(self.image_filenames)


def list_image_filenames(image_dir: Path) -> Iterable[ImageFilename]:
    """List image filenames relative to `image_dir` recursively.

    Args:
        image_dir:
            The root directory to scan for images.

    Returns:
        An iterable of image filenames relative to `image_dir`.
    """
    return (
        ImageFilename(str(fpath.relative_to(image_dir)))
        for fpath in _get_image_filepaths(image_dir=image_dir)
    )


def _get_image_filepaths(image_dir: Path) -> Iterable[Path]:
    extensions = _pil_supported_image_extensions()
    return (
        fpath for fpath in image_dir.rglob("*") if fpath.suffix.lower() in extensions
    )


def _pil_supported_image_extensions() -> Set[str]:
    return {
        ex
        for ex, format in Image.registered_extensions().items()
        if format in Image.OPEN
    }
